@@ -19,4 +19,11 @@ class Metadata(CompoundMutableDict, Resource):
             return None
 
     def __eq__(self, other):
-        return dict(self) == dict(other)
+        if not hasattr(other, '__class__'):
+            return False
+        if not self.__class__ == other.__class__:
+            return False
+        return self is other or dict(self) == dict(other)
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
